@@ -494,7 +494,7 @@ void bug_624001e (void);
 BUG_711598_DEPRECATED_FOR(bug_711598b)
 void bug_711598(void);
 
-#ifdef GTKDOC_DISABLE_DEPRECATED
+#ifdef GTKDOC_TESTER_DISABLE_DEPRECATED
 void deprecation_notice(void);
 #endif
 
@@ -504,6 +504,8 @@ void deprecation_notice(void);
 void bug_741941(void *object, void *par) G_GNUC_NONNULL(1) G_GNUC_NONNULL(2);
 
 void bug_732689 (const gchar *spec);
+void bug_749142 (void);
+
 
 /**
  * BUG_731417_DEPRECATED:
@@ -527,4 +529,19 @@ typedef enum
   BUG_730658_IS_DEPRECATED = 1 << 2
 } Bug730658;
 
+/**
+ * MACRO_VALUE:
+ *
+ * This should be listed in the types and values section.
+ */
+#define MACRO_VALUE (1 << 1)
+
+/**
+ * MACRO_FUNCTION:
+ * @x: a value
+ *
+ * This should be listed in the functions section.
+ */
+#define MACRO_FUNCTION(x) (x << 1)
+
 #endif // GTKDOC_TESTER_H
